cognitive_tests library
Classes
- StroopItem
- Unified class for all Stroop test items
- StroopLanguageWords
- Color words for each supported language Maps each language to the words for RED, GREEN, and BLUE
- StroopTest
- StroopTest - Stroop cognitive test
- StroopTestResult
- Results from the Stroop cognitive test
- StroopViewer
- Displays the Stroop test items for the current page. Scroll position resets to top whenever the page changes.
- TestResult
- Base class for all cognitive test results
- TestResultHandler
- Interface for handling cognitive test results
- TmtSheet
- Sheet widget for Trail Making Test
- TrailGestureDetector
- Gesture detector for Trail Making Test
- TrailGestureDetectorState
- TrailMakingTest
- TrailMakingTest - Contains the business logic for the Trail Making Test
- TrailMakingTestExampleViewer
- TrailMakingTestResult
- Results from the Trail Making Test
- TrailMakingTestViewer
- Widget that combines PDF viewing and gesture detection for Trail Making Test
- TrailPainter
- Custom painter for drawing trail lines
Enums
- StroopLanguage
- Supported languages for the Stroop Test
- TrailMakingTestType